@@ -32,6 +32,10 @@
 #include "flac_stubs.h"
 #include "config.h"
 
+#ifndef INT24_MAX
+#define INT24_MAX 0x007fffffL
+#endif
+
 /* Thanks you
  * http://www.linux-nantes.org/~fmonnier/ocaml/ocaml-wrapping-c.php#ref_option */
 value flac_Val_some( value v )
@@ -397,6 +401,8 @@ static inline double sample_to_double(FLAC__int32 x, unsigned bps)
       return (((double)x)/INT8_MAX);
     case 16:
       return (((double)x)/INT16_MAX);
+    case 24:
+      return (((double)x)/INT24_MAX);
     default:
       return (((double)x)/INT32_MAX);
   }
@@ -827,6 +833,8 @@ static inline FLAC__int32 sample_from_double(double x, unsigned bps)
       return x*INT8_MAX;
     case 16:
       return x*INT16_MAX;
+    case 24:
+      return x*INT24_MAX;
     default:
       return x*INT32_MAX;
   }
